@@ -4,6 +4,9 @@ from typing import Union
 from requests.exceptions import MissingSchema, ConnectionError
 from jsonrpcclient import request, parse
 from fastapi_jsonrpc import BaseError, BaseModel
+from dotenv import load_dotenv
+
+load_dotenv()
 
 
 logger = logging.getLogger(__name__)
